@@ -1,4 +1,4 @@
-#!/usr/pkg/bin/python3.10 -i
+#!/usr/bin/env python3 -i
 #
 # Copyright 2013-2022 The Khronos Group Inc.
 #
@@ -430,3 +430,16 @@ class ConventionsBase(abc.ABC):
         """Return True if generated #endif should have a comment matching
            the protection symbol used in the opening #ifdef/#ifndef."""
         return False
+
+    @property
+    def extra_refpage_headers(self):
+        """Return any extra headers (preceding the title) for generated
+           reference pages."""
+        return ''
+
+    @property
+    def extra_refpage_body(self):
+        """Return any extra text (following the title) for generated
+           reference pages."""
+        return ''
+
